# This file is an example of how to plot some outputs.
# Here, we plot 
#   - horizontal integrated heat flux (top and bottom) as a function of time
#   - integrated viscous dissipation as a function of time
#   - snapshots of the temperature field
#
# This is just a sample of the possible quantities that have been stored 
# in snapshots.h5 and analysis.h5

import os
import numpy as np
import time
import h5py
import matplotlib.pyplot as plt

from dedalus import public as de
from dedalus.extras import flow_tools
from dedalus.extras import plot_tools

import time
from IPython import display

# Read in the data
a = h5py.File('snapshots.h5','r')
T = a['tasks']['T'][:]
f = h5py.File('analysis.h5','r')
z = a['/scales/z/1.0'][:]
x = a['/scales/x/1.0'][:]
t = f['scales']['sim_time'][:]
T_ave = f['tasks']['T profile'][:]
ToDi = f['tasks']['Total_diss'][:]
heatflux = f['tasks']['heat_flux'][:]
condflux = f['tasks']['heat_flux_cond'][:]


f.close()
a.close()

ToDi = ToDi[:,0,0]
heatflux = heatflux[:,0,:]
condflux = condflux[:,0,:]

sh = T_ave.shape
di = sh[0]
fdi = sh[1]

lower_flux = condflux[:,0]
upper_flux = condflux[:,fdi-1]

# plot dissipation
t2=t[range(0,di,1)]
plt.plot(t2,ToDi)
plt.ylabel(r'Dissipation',fontsize=24)
plt.xlabel(r'$t$',fontsize=24)
plt.savefig('Diss.png')
plt.clf()

# plot heat fluxes
t2=t[range(0,di,1)]
plt.plot(t2,upper_flux,'b')
plt.plot(t2,lower_flux,'r')
plt.ylabel(r'Upper and lower heat flux',fontsize=24)
plt.xlabel(r'$t$',fontsize=24)
plt.savefig('bothflux.png')
plt.clf()

sh = T.shape
di = sh[0]

# loop on the stored fields (1 every 100)
for i in range(0,di,100):
    Tpl = T[i,:,:]
    # plot each temperature snapshot
    fig = plt.figure(figsize=(6, 3.2))
    ax = fig.add_subplot(111)
    ax.set_title('Temperature')
    plt.pcolormesh(x,z,Tpl.transpose(), vmin = np.min(T), vmax = np.max(T))
    ax.set_aspect('equal')
    nom1 = 'Temp'
    nom2 = str("%03d"%i)
    nom = nom1 + nom2 + '.png'
    nompy = nom1 + nom2 + '.npy'
    plt.savefig(nom, dpi=600)
    plt.close()


